ImageSet
========

.. currentmodule:: wwt_data_formats.imageset

.. autoclass:: ImageSet
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ImageSet.alt_url
      ~ImageSet.band_pass
      ~ImageSet.base_degrees_per_tile
      ~ImageSet.base_tile_level
      ~ImageSet.bottoms_up
      ~ImageSet.center_x
      ~ImageSet.center_y
      ~ImageSet.credits
      ~ImageSet.credits_url
      ~ImageSet.cross_validation_lock
      ~ImageSet.data_set_type
      ~ImageSet.dem_url
      ~ImageSet.description
      ~ImageSet.elevation_model
      ~ImageSet.file_type
      ~ImageSet.generic
      ~ImageSet.mean_radius
      ~ImageSet.msr_community_id
      ~ImageSet.msr_component_id
      ~ImageSet.name
      ~ImageSet.offset_x
      ~ImageSet.offset_y
      ~ImageSet.permission
      ~ImageSet.projection
      ~ImageSet.quad_tree_map
      ~ImageSet.reference_frame
      ~ImageSet.rmeta
      ~ImageSet.rotation_deg
      ~ImageSet.sparse
      ~ImageSet.stock_set
      ~ImageSet.thumbnail_url
      ~ImageSet.tile_levels
      ~ImageSet.url
      ~ImageSet.width_factor

   .. rubric:: Methods Summary

   .. autosummary::

      ~ImageSet.add_traits
      ~ImageSet.apply_to_xml
      ~ImageSet.class_own_trait_events
      ~ImageSet.class_own_traits
      ~ImageSet.class_trait_names
      ~ImageSet.class_traits
      ~ImageSet.from_file
      ~ImageSet.from_text
      ~ImageSet.from_url
      ~ImageSet.from_xml
      ~ImageSet.has_trait
      ~ImageSet.hold_trait_notifications
      ~ImageSet.mutate_urls
      ~ImageSet.notify_change
      ~ImageSet.observe
      ~ImageSet.on_trait_change
      ~ImageSet.set_position_from_wcs
      ~ImageSet.set_trait
      ~ImageSet.setup_instance
      ~ImageSet.to_xml
      ~ImageSet.to_xml_string
      ~ImageSet.trait_defaults
      ~ImageSet.trait_events
      ~ImageSet.trait_has_value
      ~ImageSet.trait_metadata
      ~ImageSet.trait_names
      ~ImageSet.trait_values
      ~ImageSet.traits
      ~ImageSet.unobserve
      ~ImageSet.unobserve_all
      ~ImageSet.wcs_headers_from_position
      ~ImageSet.write_xml

   .. rubric:: Attributes Documentation

   .. autoattribute:: alt_url
   .. autoattribute:: band_pass
   .. autoattribute:: base_degrees_per_tile
   .. autoattribute:: base_tile_level
   .. autoattribute:: bottoms_up
   .. autoattribute:: center_x
   .. autoattribute:: center_y
   .. autoattribute:: credits
   .. autoattribute:: credits_url
   .. autoattribute:: cross_validation_lock
   .. autoattribute:: data_set_type
   .. autoattribute:: dem_url
   .. autoattribute:: description
   .. autoattribute:: elevation_model
   .. autoattribute:: file_type
   .. autoattribute:: generic
   .. autoattribute:: mean_radius
   .. autoattribute:: msr_community_id
   .. autoattribute:: msr_component_id
   .. autoattribute:: name
   .. autoattribute:: offset_x
   .. autoattribute:: offset_y
   .. autoattribute:: permission
   .. autoattribute:: projection
   .. autoattribute:: quad_tree_map
   .. autoattribute:: reference_frame
   .. autoattribute:: rmeta
   .. autoattribute:: rotation_deg
   .. autoattribute:: sparse
   .. autoattribute:: stock_set
   .. autoattribute:: thumbnail_url
   .. autoattribute:: tile_levels
   .. autoattribute:: url
   .. autoattribute:: width_factor

   .. rubric:: Methods Documentation

   .. automethod:: add_traits
   .. automethod:: apply_to_xml
   .. automethod:: class_own_trait_events
   .. automethod:: class_own_traits
   .. automethod:: class_trait_names
   .. automethod:: class_traits
   .. automethod:: from_file
   .. automethod:: from_text
   .. automethod:: from_url
   .. automethod:: from_xml
   .. automethod:: has_trait
   .. automethod:: hold_trait_notifications
   .. automethod:: mutate_urls
   .. automethod:: notify_change
   .. automethod:: observe
   .. automethod:: on_trait_change
   .. automethod:: set_position_from_wcs
   .. automethod:: set_trait
   .. automethod:: setup_instance
   .. automethod:: to_xml
   .. automethod:: to_xml_string
   .. automethod:: trait_defaults
   .. automethod:: trait_events
   .. automethod:: trait_has_value
   .. automethod:: trait_metadata
   .. automethod:: trait_names
   .. automethod:: trait_values
   .. automethod:: traits
   .. automethod:: unobserve
   .. automethod:: unobserve_all
   .. automethod:: wcs_headers_from_position
   .. automethod:: write_xml
